@@ -3,41 +3,41 @@ import kubify.k8s_utils.k8s as module_0
 
 def test_case_0():
     try:
-        k8s_utils_0 = module_0.k8s_utils()
+        module_0.k8s_utils()
     except BaseException:
         pass
 
 
 def test_case_1():
     try:
-        k8s_utils_0 = module_0.k8s_utils()
+        module_0.k8s_utils()
     except BaseException:
         pass
 
 
 def test_case_2():
     try:
-        k8s_utils_0 = module_0.k8s_utils()
+        module_0.k8s_utils()
     except BaseException:
         pass
 
 
 def test_case_3():
     try:
-        k8s_utils_0 = module_0.k8s_utils()
+        module_0.k8s_utils()
     except BaseException:
         pass
 
 
 def test_case_4():
     try:
-        k8s_utils_0 = module_0.k8s_utils()
+        module_0.k8s_utils()
     except BaseException:
         pass
 
 
 def test_case_5():
     try:
-        k8s_utils_0 = module_0.k8s_utils()
+        module_0.k8s_utils()
     except BaseException:
         pass
